package com.ruoyi.interfaces.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.interfaces.mapper.SysMetaTableMapper;
import com.ruoyi.interfaces.domain.SysMetaTable;
import com.ruoyi.interfaces.service.ISysMetaTableService;

/**
 * 元数据表Service业务层处理
 * 
 * @author 朱得糠
 * @date 2025-08-02
 */
@Service
public class SysMetaTableServiceImpl implements ISysMetaTableService 
{
    @Autowired
    private SysMetaTableMapper sysMetaTableMapper;

    /**
     * 查询元数据表
     * 
     * @param dsCode 元数据表主键
     * @return 元数据表
     */
    @Override
    public List<SysMetaTable> selectSysMetaTableByDsCode(String dsCode)
    {
        return sysMetaTableMapper.selectSysMetaTableByDsCode(dsCode);
    }

    /**
     * 查询元数据表列表
     * 
     * @param sysMetaTable 元数据表
     * @return 元数据表
     */
    @Override
    public List<SysMetaTable> selectSysMetaTableList(SysMetaTable sysMetaTable)
    {
        return sysMetaTableMapper.selectSysMetaTableList(sysMetaTable);
    }

    /**
     * 新增元数据表
     * 
     * @param sysMetaTable 元数据表
     * @return 结果
     */
    @Override
    public int insertSysMetaTable(SysMetaTable sysMetaTable)
    {
        return sysMetaTableMapper.insertSysMetaTable(sysMetaTable);
    }

    /**
     * 修改元数据表
     * 
     * @param sysMetaTable 元数据表
     * @return 结果
     */
    @Override
    public int updateSysMetaTable(SysMetaTable sysMetaTable)
    {
        return sysMetaTableMapper.updateSysMetaTable(sysMetaTable);
    }


    /**
     * 删除元数据表信息
     * 
     * @param dsCode 元数据表主键
     * @return 结果
     */
    @Override
    public int deleteSysMetaTable(SysMetaTable sysMetaTable)
    {
        return sysMetaTableMapper.deleteSysMetaTable(sysMetaTable);
    }
}
